@@ -1,4 +1,5 @@
 """Module to hold the `TomlSource` class definition."""
+
 from functools import lru_cache
 from typing import Any
 from typing import Dict
@@ -20,7 +21,7 @@ class TomlSource(BaseSource):
         """
         return self._load_file()
 
-    @lru_cache()
+    @lru_cache
     def _load_file(self) -> Dict[Any, Any]:
         """Load the `.toml` file.
 
