@@ -1,4 +1,5 @@
 """Tests for the `TomlSource` class."""
+
 import re
 from pathlib import Path
 from textwrap import dedent
@@ -14,22 +15,15 @@ class TestToDict:
     """Tests for the `to_dict` method."""
 
     def test_success(self, create_toml: Callable[..., Path]) -> None:
-        """
-        Given an instance of `TomlSource` instantiated with a `.toml` file,
-        When the `to_dict` method is called,
-        Then the `.toml` is loaded and converted to a `dict`
-        """
+        """A `.toml` is loaded and converted to a `dict`"""
         toml_path = create_toml(filename="config.toml", content={"foo": "bar"})
 
-        toml_source = TomlSource(filepath=toml_path, project_name="acme")
+        toml_source = TomlSource(filepath=toml_path, package_name="acme")
 
         assert toml_source.to_dict() == {"foo": "bar"}
 
     def test_toml_decode_error(self, create_toml: Callable[..., Path]) -> None:
-        """
-        Given a `.toml` file containing duplicate keys, report on the filepath
-        of the `.toml` file that triggered the error.
-        """
+        """Toml decoding errors are reported"""
         toml_path = create_toml(filename="config.toml")
         toml_path.write_text(
             dedent(
@@ -41,7 +35,7 @@ class TestToDict:
             encoding="utf-8",
         )
 
-        toml_source = TomlSource(filepath=toml_path, project_name="acme")
+        toml_source = TomlSource(filepath=toml_path, package_name="acme")
 
         error_regex = re.escape(f"Error trying to load toml file '{toml_path!s}'")
         with pytest.raises(BadTomlError, match=error_regex):
